@@ -16,7 +16,7 @@ the usage of the following ae namespace portions get demonstrated by this applic
 * :mod:`ae.deep`: deep data structure search and replace
 * :mod:`ae.i18n`: internationalization / localization helpers
 * :mod:`ae.paths`: generic file path helpers
-* :mod:`ae.inspector`: inspection and debugging helper functions
+* :mod:`ae.dynamicod`: evaluation and execution helper functions
 * :mod:`ae.updater`: application environment updater
 * :mod:`ae.core`: application core constants, helper functions and base classes
 * :mod:`ae.literal`: literal type detection and evaluation
@@ -127,42 +127,36 @@ the `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `k
     * - .. figure:: ../img/kivy_lisz_root.png
            :alt: root list of a dark themed kivy lisz app
            :scale: 30 %
-           :target: ../img/kivy_lisz_root.png
 
            kivy lisz app root list
 
       - .. figure:: ../img/kivy_lisz_fruits.png
            :alt: fruits sub-list of a dark themed kivy lisz app
            :scale: 30 %
-           :target: ../img/kivy_lisz_fruits.png
 
            fruits sub-list
 
       - .. figure:: ../img/kivy_lisz_fruits_light.png
            :alt: fruits sub-list of a light themed kivy lisz app
            :scale: 30 %
-           :target: ../img/kivy_lisz_fruits_light.png
 
            using light theme
 
     * - .. figure:: ../img/kivy_lisz_user_prefs.png
            :alt: user preferences dropdown
            :scale: 30 %
-           :target: ../img/kivy_lisz_user_prefs.png
 
            lisz user preferences
 
       - .. figure:: ../img/kivy_lisz_color_editor.png
            :alt: kivy lisz color editor
            :scale: 30 %
-           :target: ../img/kivy_lisz_color_editor.png
 
            kivy lisz color editor
 
       - .. figure:: ../img/kivy_lisz_font_size_big.png
            :alt: lisz app using bigger font size
            :scale: 30 %
-           :target: ../img/kivy_lisz_font_size_big.png
 
            bigger font size
 
@@ -186,14 +180,12 @@ the `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is based on
     * - .. figure:: ../img/enaml_lisz_fruits_sub_list.png
            :alt: fruits sub-list of dark themed enaml lisz app
            :scale: 27 %
-           :target: ../img/enaml_lisz_fruits_sub_list.png
 
            enaml/qt lisz app
 
       - .. figure:: ../img/enaml_lisz_light_landscape.png
            :alt: fruits sub-list of a light themed enaml lisz app in landscape
            :scale: 66 %
-           :target: ../img/enaml_lisz_light_landscape.png
 
            light themed in landscape
 
@@ -236,7 +228,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.3.47'
+__version__ = '0.3.48'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -640,7 +632,7 @@ class LiszDataMixin:
                 flow_path.append(id_of_flow('enter', 'item', flo_key))
         return flow_path
 
-    def flow_path_node(self, flow_path: List[str] = None, create: bool = False) -> LiszNode:
+    def flow_path_node(self, flow_path: Optional[List[str]] = None, create: bool = False) -> LiszNode:
         """ determine the node specified by the passed flow path, optionally create missing nodes of the flow path.
 
         :param flow_path:       flow path list.
